@@ -1,6 +1,6 @@
 package MARC::Moose::Lint::Checker::RulesFile;
 # ABSTRACT: A class to 'lint' biblio record based on a rules file
-$MARC::Moose::Lint::Checker::RulesFile::VERSION = '1.0.18';
+$MARC::Moose::Lint::Checker::RulesFile::VERSION = '1.0.19';
 use Moose;
 use Modern::Perl;
 
@@ -118,7 +118,7 @@ sub check {
         push @text, ": ", shift;
         push @warnings, join('', @text);
     };
-    my $fields_by_tag;
+    my $fields_by_tag = { '000' => [ $record->leader ] };
     for my $field ( @{$record->fields} ) {
         $fields_by_tag->{$field->tag} ||= [];
         push @{$fields_by_tag->{$field->tag}}, $field;
@@ -152,15 +152,21 @@ sub check {
 
         $i_field = 1;
 
-        # Control field
+        # Control field & leader
         if ( $tag lt '010' ) {
             my $regexp;
             (undef, undef, undef, $regexp) = @$rule;
             if ( $regexp ) {
-                for my $field (@fields) {
-                    $append->("invalid value, doesn't match /$regexp/")
-                        if $field->value !~ /$regexp/; 
-                    $i_field++;
+                if ( $tag eq '000') {
+                    $append->("invalid leader, doesn't match /$regexp/")
+                        if $record->leader !~ /$regexp/;                 
+                }
+                else {
+                    for my $field (@fields) {
+                        $append->("invalid value, doesn't match /$regexp/")
+                            if $field->value !~ /$regexp/; 
+                        $i_field++;
+                    }
                 }
             }
             next;
@@ -220,7 +226,7 @@ sub check {
         }
     }
 
-    return @warnings;
+    sort @warnings;
 }
 
 
@@ -240,7 +246,7 @@ MARC::Moose::Lint::Checker::RulesFile - A class to 'lint' biblio record based on
 
 =head1 VERSION
 
-version 1.0.18
+version 1.0.19
 
 =head1 DESCRIPTION
 
@@ -289,6 +295,25 @@ B<Indicator values> - Authorised values for indicators 1 and 2 are specified in
 validation rule. When a field uses another value, a warning is emitted saying
 I<invalid indicator value>.
 
+=item *
+
+B<Field content> - The content of a field, control field value, or subfield
+value, can be tested on a regular expression. This way it's possible to check
+that a field comply to a specific format. C<.{3}> will accept values with 3
+characters length. C<[0-9]{8}> will accept digit-only value with 8 digits. And
+this regular expression will validate UNIMARC 100 code field:
+
+ ^[0-9]{8}[a-ku][0-9 ]{8}[abcdeklu ]{3}[a-huyz][01 ][a-z]{3}[a-cy][01|02|03|04|05|06|07|08|09|10|11|50]{2}
+
+=item *
+
+B<Validation tables> - Validation tables can be specified. For example, table
+of ISO language codes. Field/subfield content can be validated against a table
+in order to identify unauthorised values. When such a value is found, a warning
+is emitted saying that I<this value> is not in I<this table>.
+
+=back
+
 =head1 ATTRIBUTES
 
 =head2 file
@@ -323,32 +348,17 @@ the reasons why the record doesn't comply with validation rules.
      }
  }
 
-=items *
-
-B<Field content> - The content of a field, control field value, or subfield
-value, can be tested on a regular expression. This way it's possible to check
-that a field comply to a specific format. C<.{3}> will accept values with 3
-characters length. C<[0-9]{8}> will accept digit-only value with 8 digits. And
-this regular expression will validate UNIMARC 100 code field:
-
- ^[0-9]{8}[a-ku][0-9 ]{8}[abcdeklu ]{3}[a-huyz][01 ][a-z]{3}[a-cy][01|02|03|04|05|06|07|08|09|10|11|50]{2}
-
-=item *
-
-B<Validation tables> - Validation tables can be specified. For example, table
-of ISO language codes. Field/subfield content can be validated against a table
-in order to identify unauthorised values. When such a value is found, a warning
-is emitted saying that I<this value> is not in I<this table>.
-
-=back
-
 =head1 VALIDATION RULES
 
 Validation rules are defined in a textual form. The file is composed of two
 parts: (1) B<field rules>, (2) B<validation tables>.
 
-(1) B<Field rules> define validation rules for each tag. A blank line separates
-tags. For example:
+=over
+
+=item B<(1) Field rules>
+
+Define validation rules for each tag. A blank line separates tags. For
+example:
 
  102+
  #
@@ -367,12 +377,21 @@ optional validation table name begining with @. A blank separates the first
 part from the second part. The second part contains a regular expression on
 which subfield content is validated.
 
-(2) B<Validation tables> part of the file allow to define several validation
-tables. The table name begins with C<==== TABLE NAME> in uppercase. Then each
-line is a code in the validation table.
+=item B<(2) Validation tables>
+
+This part of the file allows to define several validation tables. The table
+name begins with C<==== TABLE NAME> in uppercase. Then each line is a code in
+the validation table.
+
+=back
 
 This is for example, a simplified standard UNIMARC validation rules file:
 
+ 000
+ .{5}[cdnop][abcdefgijklmr][aimsc][ 012]
+
+ 001_
+ 
  005
  \d{14}\.\d
 
